@@ -137,6 +137,9 @@ class Emulator(object):
             self.qemu.expect("Password:")
             self.qemu.sendline(password)
 
+        self.connect_shell()
+
+    def connect_shell(self):
         extra_init_cmd = " && ".join([
             'export PAGER=cat',
             'dmesg -n 1',
